boss.dummies - heros-boss 0.6.10 documentation

Skip to content
Back to top
View this page

# boss.dummies

## Classes

`Dummy` |
`DependentDummy` |
`PolledDatasourceDummy` |

## Module Contents

class boss.dummies.Dummy
  testme: int = 0
  val = 3
  read_temp(min: int, max: int) → float
  hello() → str
  _secret_hello() → str
  blocking_call(block_time: int)

class boss.dummies.DependentDummy(parent_hero)
  parent
  update_parent_testme(value: int)

class boss.dummies.PolledDatasourceDummy

  Bases: `Dummy`

  foovar: str = ''
  testme: int = 0
  _observable_data()